@@ -123,18 +123,30 @@ class Immutable(Restful):
 
         :returns: list -- a list of objects that match the query
         """
-        objects = []
+        restful = []
         endpoint = getattr(cls, 'endpoint', None)
         assert endpoint, "Endpoint not specified for %s" % cls.__name__
 
-        json = send_request('GET', endpoint, params=kwargs)
-        if json:
-            json_objects = json.get('objects', [])
-            for json_obj in json_objects:
-                instance = cls()
-                instance._loaddict(json_obj)
-                objects.append(instance)
-        return objects
+        objects=[]
+        while True:
+            json = send_request('GET', endpoint, params=kwargs)
+            objs = json.get('objects', [])
+            meta = json.get('meta', {})
+            next_url = meta.get('next', '')
+            offset = meta.get('offset', 0)
+            limit = meta.get('limit', 0)
+            objects.extend(objs)
+            if next_url:
+                kwargs['offset'] = offset + limit
+                kwargs['limit'] = limit
+            else:
+                break
+
+        for obj in objects:
+            instance = cls()
+            instance._loaddict(obj)
+            restful.append(instance)
+        return restful
 
     def refresh(self, force=False):
         """Reloads the object with remote information
@@ -166,24 +178,14 @@ class Mutable(Immutable):
         """
         return cls(**kwargs)
 
-    def delete(self, suffix=""):
+    def delete(self):
         """Deletes the object in Tutum
-
-        :param suffix: delete affiliated stuff attached the object, like tags etc.
-        :type suffix: string
         :returns: bool -- whether the operation was successful or not
         """
         if not self._detail_uri:
             raise TutumApiError("You must save the object before performing this operation")
         action = "DELETE"
         url = self._detail_uri
-        if suffix:
-            if suffix.startswith("/"):
-                suffix = suffix[1:]
-            if url.endswith("/"):
-                url = "".join([url, suffix])
-            else:
-                url = "/".join([url, suffix])
         json = send_request(action, url)
         if json:
             self._loaddict(json)
@@ -235,61 +237,9 @@ class Mutable(Immutable):
         return success
 
 
-class Taggable(Restful):
-    class Tag(object):
-        def __init__(self, restful):
-            self.restful = restful
+class Taggable(object):
+    pass
 
-        def add(self, tag):
-            return self.restful._tag_add(tag)
 
-        def delete(self, tag):
-            return self.restful._tag_delete(tag)
-
-        def list(self):
-            return self.restful._tag_list()
-
-    @property
-    def tag(self):
-        return Taggable.Tag(self)
-
-    def _tag_add(self, tag):
-        """Adds a tag from a taggable object
-
-        :param tag: the tag name to be added
-        :type tag: string
-        :returns: bool -- whether the operation was successful or not
-        """
-        if not self._detail_uri:
-            raise TutumApiError("You must save the object before performing this operation")
-        url = "/".join([self._detail_uri, 'tags'])
-        data = []
-        if isinstance(tag, list):
-            for t in tag:
-                data.append({"name": t})
-        else:
-            data.append({"name": tag})
-        json = send_request("POST", url, data=json_parser.dumps(data))
-        if json:
-            return True
-        return False
-
-    def _tag_delete(self, tag):
-        """Deletes a tag from a taggable object
-
-        :param tag: the tag name to be deleted
-        :type tag: string
-        :returns: bool -- whether the operation was successful or not
-        """
-        return self.delete("tags/%s" % tag)
-
-    def _tag_list(self):
-        """List all tags for the taggable objects
-
-        :returns: list -- a list of tags that match the query
-        """
-        url = "/".join([self._detail_uri, "tags"])
-        json = send_request('GET', url)
-        if json:
-            return json.get('objects', [])
-        return []
\ No newline at end of file
+class Webhookable(object):
+    pass
\ No newline at end of file
